import java.io.*;
import java.net.*;
import java.rmi.*;
import java.rmi.server.*;


// Classe de l'objet RMI
//
public class GerantMagasin 
	extends UnicastRemoteObject  implements Magasin    
{

	// Tables contenant le nom et le prix des ingredients
	//
	String[] NomIngredients = new String[100] ;
	Float[] PrixIngredients = new Float [100];
	int Compteur = 0 ;
  

	// Le constructeur de la classe charge les tables 
	// ci-dessus a partir du fichier "NomFichier"
	//
	public GerantMagasin (String NomFichier) throws RemoteException, IOException
	{
		BufferedReader Ingredients = null;
		String Ligne;
		int i = 0;
      
      
		// Ouvrir le fichier  
		//
		try 
		{
			Ingredients = new BufferedReader(new FileReader(NomFichier));
		}
		catch(FileNotFoundException exc) 
		{
			System.out.println("Erreur d'ouverture");
			System.exit(0);
		}
      

		// Lecture du fichier pour en extraire les prix 
		// et les noms des ingredients disponibles
		//
		while ((Ligne = Ingredients.readLine()) != null)
		{
			System.out.println("Ingredient numero " + i + " : " +  Ligne);
			if ( (Compteur%2) == 0) 
				NomIngredients[i] = Ligne;
			else 	{
				PrixIngredients[i] = Float.valueOf(Ligne);
				i = i+1;
				}

			Compteur = Compteur+1;

		}

		Ingredients.close();
           
	}
  

	// La methode appelee a distance
	// Cette methode consulte les tables chargees ci-dessus pour rechercher
	// le prix de l'ingredient demande
	//
	public float RenvoyerPrix (String Ingredient) throws java.rmi.RemoteException
	{

		for (int i = 0; i < Compteur/2; i++)
			if (NomIngredients[i].equals(Ingredient))
				return PrixIngredients[i].floatValue(); 
	  
		return -1;
	}
  

	//Methode principale
	//
	public static void main(String args[]) throws IOException
	{
		GerantMagasin MonServeur    = null;
     
		if (args.length != 2)
		{
			System.out.println("Deux parametres : portRmiRegistry nom-du-fichier ! ");
			System.exit(1);
		}
      

		// Creation et installation du security manager
		//
		if (System.getSecurityManager() == null) 
			System.setSecurityManager(new RMISecurityManager());
 
 
		// Creation de l'objet qui va etre appele par des clients distants
		// puis, publication du service au rmiregistry
		//

		try 
		{
	
			// Creation de l'objet
			//
			MonServeur = new GerantMagasin(args[1]);
	
			// Publication du service
			//
			MyHostName machine = new MyHostName();
			String nom = "//" + machine.QualifiedHost() + ":" + args[0] + "/GerantMagasin";

			Naming.rebind(nom, MonServeur);
			System.out.println("GerantMagasin enregistre : " + nom);
		} 
		catch (RemoteException e) 
		{
			System.out.println("GerantMagasin err: " + e.getMessage());
			e.printStackTrace();
		}
	}
}


